@@ -1,4 +1,4 @@
-"PLACKETTcop" <-
+"PLcop" <-
 function(u, v, para=NULL, ...) {
     T <- para[1]
     if(is.null(para)) {
@@ -9,7 +9,7 @@ function(u, v, para=NULL, ...) {
        warning("Theta < 0, invalid parameter")
        return()
     }
-    if(T == 1)         return(u*v)    # the product copula
+    if(T == 1)         return(  u*v)  # the product copula
     if(T == 0)         return(W(u,v)) # lower copula bounds
     if(! is.finite(T)) return(M(u,v)) # upper copula bounds
     cop <- 1+(T-1)*(u+v)
@@ -17,3 +17,7 @@ function(u, v, para=NULL, ...) {
     cop <- cop / (2*(T-1))
     return(cop)
 }
+
+"PLACKETTcop" <- function(u, v, para=NULL, ...) {
+   PLcop(u, v, para=para, ...)
+}
